﻿init python:
    renpy.music.register_channel("sfx1", "sfx", True)
    def find_coordinations(x, y):
        x = x*4
        y = y*4
        return ((x - y) * 32, ((x + y) * 32)//2)
    class iso_player:
        def __init__(self, name, image, throws):
            self.name = name
            self.image = image
            self.throws = throws
            self.x = 0
            self.y = 0
            self.camera_x = 0
            self.camera_y = 0
            self.collection = {
                "iso_heart": 0,
                "iso_skull": 0,
                "iso_sword": 0,
                "iso_face": 0,
                "iso_star": 0,
                "iso_time": 0,
                "iso_upgrade": 0,
            }


    class iso_tile:
        def __init__(self, tile, icon, x, y, info = ""):
            self.tile = tile
            self.icon = icon
            self.info = info
            self.x = x
            self.y = y

    class iso_board_class:
        def __init__(self, tiles, icons, map, objects, players, focus = (0,0)):
            self.tiles = tiles
            self.icons = icons
            self.map = map
            self.objects = objects
            self.players = players

            self.camera_x = 0
            self.camera_y = 0
            self.change_focus(*focus)
            for i in players:
                i.x,i.y = focus
                i.camera_x, i.camera_y = find_coordinations(*focus)
        def change_focus(self, x, y):
            c = find_coordinations(x, y)
            self.camera_x = -c[0]
            self.camera_y = -c[1]
        def settle(self):
            player = self.players[0]
            object = self.objects[player.y][player.x]
            if object == 1:
                pass
            elif object:
                player.collection[self.icons[object]] += 1
                self.objects[player.y][player.x] = None
        def move(self, direction):
            player = self.players[0]
            if direction == "w":
                if player.y > 0 and self.map[player.y - 1][player.x]:
                    player.y -= 1
            elif direction == "s":
                if player.y < len(self.map)-1 and self.map[player.y + 1][player.x]:
                    player.y += 1
            elif direction == "a":
                if player.x > 0 and self.map[player.y][player.x - 1]:
                    player.x -= 1
            elif direction == "d":
                if player.x < len(self.map[0])-1 and self.map[player.y][player.x + 1]:
                    player.x += 1

            # renpy.notify(self.map[player.x][player.y])
            player.camera_x, player.camera_y = find_coordinations(player.x, player.y)
            self.change_focus(player.x, player.y)


screen iso_board_screen():
    modal True
    default g = iso_board_class(
        tiles = all_iso_tiles,
        icons = all_iso_icon,
        map = csv_to_array("iso board/level_1_board.csv", 1),
        objects = csv_to_array("iso board/level_1_objects.csv", -7),
        players = [
            iso_player("Mako", "mako", 15),
            iso_player("Liz", "liz", 15),
        ],
        focus = (3,12)
        )

    fixed fit_first True:
        at iso_board_camera(g.camera_x, g.camera_y)
        align .5,.5
        fixed fit_first True:
            at zoom(4, True)
            align .5,.5
            for y,j in enumerate(g.map):
                for x,i in enumerate(j):
                    if i:
                        button:
                            offset ((x - y) * 32), ((x + y) * 32)//2
                            fixed fit_first True:
                                add g.tiles[i]
                                # text "[x],[y]" size 10 align .5,.5
                            at iso_board_button
                            focus_mask True
                            action Function(g.change_focus, x, y)
        fixed fit_first True:
            at zoom(4, True)
            align .5,.5
            for y,j in enumerate(g.objects):
                for x,i in enumerate(j):
                    if i:
                        fixed fit_first True:
                            offset ((x - y) * 32), ((x + y) * 32)//2
                            add g.icons[i]
        for i in g.players:
            fixed fit_first True:
                align .5,.0
                at iso_player_move(i.camera_x, i.camera_y)
                add i.image at zoom(4, True)
                # text "[i.x],[i.y]"
    # collection
    vbox:
        for key,value in g.players[0].collection.items():
            hbox:
                add key at zoom(3, True)
                text str(value)


    # Touch
    fixed fit_first True:
        align 0,1.0 offset 128,-64
        at zoom (3, True)
        button:
            padding 0,0 background None
            fixed fit_first True:
                add "iso_tile_white"
                add "iso_place" align .5,.5
            action Function(g.settle) keysym "K_SPACE"
        button:
            padding 0,0 background None offset (32, -16)
            fixed fit_first True:
                add "iso_tile_white"
                add "iso_arrow_1" align .5,.5
            action Function(g.move, "w") keysym "w"
        button:
            padding 0,0 background None offset (-32, 16)
            fixed fit_first True:
                add "iso_tile_white"
                add "iso_arrow_4" align .5,.5
            action Function(g.move, "s") keysym "s"

        button:
            padding 0,0 background None offset (-32, -16)
            fixed fit_first True:
                add "iso_tile_white"
                add "iso_arrow_2" align .5,.5
            action Function(g.move, "a") keysym "a"
        button:
            padding 0,0 background None offset (32, 16)
            fixed fit_first True:
                add "iso_tile_white"
                add "iso_arrow_3" align .5,.5
            action Function(g.move, "d") keysym "d"

transform iso_player_move(x, y):
    ease .4 offset(x,y)
transform iso_board_camera(x, y):
    ease 1 offset(x,y)
transform iso_board_button(x, y):
    on idle:
        ease .2 additive 0
    on hover:
        ease .2 additive .3

init:
    image mako = Crop((0,0,16,32), "iso board/sprites.png")
    image sai = Crop((16,0,16,32), "iso board/sprites.png")
    image liz = Crop((32,0,16,32), "iso board/sprites.png")
    image kaga = Crop((48,0,16,32), "iso board/sprites.png")
    image mi = Crop((64,0,16,32), "iso board/sprites.png")

    image iso_tile_gray = Crop((0,64,64,48), "iso board/sprites.png")
    image iso_tile_blue = Crop((64,64,64,48), "iso board/sprites.png")
    image iso_tile_pink = Crop((128,64,64,48), "iso board/sprites.png")
    image iso_tile_green = Crop((192,64,64,48), "iso board/sprites.png")
    image iso_tile_brown = Crop((0,112,64,48), "iso board/sprites.png")
    image iso_tile_black = Crop((64,112,64,48), "iso board/sprites.png")
    image iso_tile_white = Crop((128,112,64,48), "iso board/sprites.png")
    default all_iso_tiles = [
        None,
        "iso_tile_gray",
        "iso_tile_blue",
        "iso_tile_pink",
        "iso_tile_green",
        "iso_tile_brown",
        "iso_tile_black",
        ]

    image iso_start = Crop((0,160,32,16), "iso board/sprites.png")
    image iso_heart = Crop((32,160,32,16), "iso board/sprites.png")
    image iso_skull = Crop((64,160,32,16), "iso board/sprites.png")
    image iso_sword = Crop((96,160,32,16), "iso board/sprites.png")
    image iso_face = Crop((128,160,32,16), "iso board/sprites.png")
    image iso_star = Crop((160,160,32,16), "iso board/sprites.png")
    image iso_time = Crop((192,160,32,16), "iso board/sprites.png")
    image iso_upgrade = Crop((224,160,32,16), "iso board/sprites.png")
    default all_iso_icon = [
        None,
        "iso_start",
        "iso_heart",
        "iso_skull",
        "iso_sword",
        "iso_face",
        "iso_star",
        "iso_time",
        "iso_upgrade",
        ]

    image iso_arrow_1 = Crop((0,176,32,16), "iso board/sprites.png")
    image iso_arrow_2 = Crop((32,176,32,16), "iso board/sprites.png")
    image iso_arrow_3 = Crop((64,176,32,16), "iso board/sprites.png")
    image iso_arrow_4 = Crop((92,176,32,16), "iso board/sprites.png")

    image iso_place = Crop((128,176,32,16), "iso board/sprites.png")

label iso_board_example:
    show image "#30702c"
    call screen iso_board_screen